@@ -962,6 +962,8 @@ ItclFreeObject(cdata)
     ItclContext context;
     Itcl_InterpState istate;
 
+    int dataSize = contextObj->dataSize;
+
     /*
      *  Install the class namespace and object context so that
      *  the object's data members can be destroyed via simple
@@ -1013,6 +1015,8 @@ ItclFreeObject(cdata)
     }
     Itcl_DeleteHierIter(&hier);
 
+    contextObj->dataSize = -1;
+
     /*
      *  Free the memory associated with object-specific variables.
      *  For normal variables this would be done automatically by
@@ -1020,9 +1024,11 @@ ItclFreeObject(cdata)
      *  variables are protected by an extra reference count, and they
      *  must be deleted explicitly here.
      */
-    for (i=0; i < contextObj->dataSize; i++) {
-        if (contextObj->data[i]) {
-            ckfree((char*)contextObj->data[i]);
+    for (i=0; i < dataSize; i++) {
+	Var *varPtr = contextObj->data[i];
+        if (varPtr) {
+	    assert(TclIsVarUndefined(varPtr));
+            ckfree((char*)varPtr);
         }
     }
 
@@ -1196,7 +1202,8 @@ Itcl_ScopedVarResolver(interp, name, contextNs, flags, rPtr)
      *  Look for the command representing the object and extract
      *  the object context.
      */
-    if (!Tcl_GetCommandInfo(interp, namev[1], &cmdInfo)) {
+    if (!Tcl_GetCommandInfo(interp, namev[1], &cmdInfo)
+	    || cmdInfo.objProc != Itcl_HandleInstance) {
         if (errs) {
             Tcl_AppendResult(errs,
                 "can't resolve scoped variable \"", name, "\": ",
@@ -1207,6 +1214,10 @@ Itcl_ScopedVarResolver(interp, name, contextNs, flags, rPtr)
         return TCL_ERROR;
     }
     contextObj = (ItclObject*)cmdInfo.objClientData;
+    if (contextObj->dataSize < 0) {
+	/* Don't resolve names into dying objects */
+        return TCL_ERROR;
+    }
 
     /*
      *  Resolve the variable with respect to the most-specific
